@@ -7,7 +7,7 @@ use warnings;
 use English qw< -no_match_vars >;
 use Data::Dumper;
 use Scalar::Util qw< blessed >;
-our $VERSION = '0.732';
+our $VERSION = '0.734';
 
 use Log::Log4perl::Tiny
   qw< :easy :dead_if_first get_logger LOGLEVEL LEVELID_FOR >;
@@ -171,7 +171,7 @@ sub dispatch {
         unless defined $key;
 
       # register a new handler... or die!
-      $handler_for->{$key} = $factory->($key, $record)
+      ($handler_for->{$key}) = tubify($factory->($key, $record))
         unless exists $handler_for->{$key};
 
       return $handler_for->{$key}->($record);
