@@ -2,7 +2,7 @@ package Data::Tubes::Plugin::Validator;
 use strict;
 use warnings;
 use English qw< -no_match_vars >;
-our $VERSION = '0.732';
+our $VERSION = '0.734';
 
 use Log::Log4perl::Tiny qw< :easy :dead_if_first >;
 
@@ -69,7 +69,8 @@ sub validate_refuse_empty {
    return validate_refuse(qr{(?mxs:\A \s* \z)}, $args);
 } ## end sub validate_refuse_empty
 
-sub validate_with_subs {
+
+sub validate_thoroughly {
    my ($validators, $args) = args_array_with_options(
       @_,
       {
@@ -115,7 +116,13 @@ sub validate_with_subs {
          my @outcome =
              $wrapper
            ? $wrapper->($validator, $target, $record, $args, @params)
-           : $validator->($target, $record, $args, @params);
+           : (ref($validator) eq 'CODE')
+           ? $validator->($target, $record, $args, @params)
+           : (
+               $target =~ m{$validator}
+               ? (1)
+               : (0, regex => "$validator")
+            );
          push @outcome, 0 unless @outcome;
          push @outcomes, [$name, @outcome]
            if !$outcome[0] || $keep_positives;
@@ -126,6 +133,8 @@ sub validate_with_subs {
    };
 } ## end sub validate_with_subs
 
+*validate_with_subs = \&validate_thoroughly;
+
 shorter_sub_names(__PACKAGE__, 'validate_');
 
 1;
